###################################################################################################
#
# Copyright (C) 2020 Maxim Integrated Products, Inc. All Rights Reserved.
#
# Maxim Integrated Products, Inc. Default Copyright Notice:
# https://www.maximintegrated.com/en/aboutus/legal/copyrights.html
#
###################################################################################################
"""
ihappy Datasets
"""
import os
import shutil
import sys
from os import listdir, makedirs
from random import random

import torchvision
from torchvision import transforms

import ai8x


def ihappy_get_datasets(data, load_train=True, load_test=True):
    """
    Load Cats & Dogs dataset
    """
    (data_dir, args) = data
    path = data_dir

    training_data_path = os.path.join(data_dir, "iHappy")
    training_data_path = os.path.join(training_data_path, "train")

    test_data_path = os.path.join(data_dir, "iHappy")
    test_data_path = os.path.join(test_data_path, "test")

    # Loading and normalizing train dataset
    if load_train:
        train_transform = transforms.Compose([
            transforms.Resize((64, 64)),
            transforms.RandomAffine(degrees=20, translate=(0.1, 0.1), shear=5),
            transforms.ToTensor(),
            ai8x.normalize(args=args)
        ])

        train_dataset = torchvision.datasets.ImageFolder(root=training_data_path,
                                                         transform=train_transform)
    else:
        train_dataset = None

    # Loading and normalizing test dataset
    if load_test:
        test_transform = transforms.Compose([
            transforms.Resize((64, 64)),
            transforms.ToTensor(),
            ai8x.normalize(args=args)
        ])

        test_dataset = torchvision.datasets.ImageFolder(root=test_data_path,
                                                        transform=test_transform)

        if args.truncate_testset:
            test_dataset.data = test_dataset.data[:1]
    else:
        test_dataset = None

    return train_dataset, test_dataset


datasets = [
    {
        'name': 'ihappy',
        'input': (3, 64, 64),
        'output': ('happy', 'nothappy'),
        'loader': ihappy_get_datasets,
    },
]
